#
# spec file for package udftools
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           udftools
Version:        2.3
Release:        1.14
Summary:        UDF filesystem tools
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://github.com/pali/udftools
Source:         https://github.com/pali/udftools/releases/download/%{version}/udftools-%{version}.tar.gz
BuildRequires:  autoconf >= 2.64
BuildRequires:  automake
BuildRequires:  glibc
BuildRequires:  libtool
BuildRequires:  pkgconfig(udev)
Provides:       udf = %{version}
Obsoletes:      udf < %{version}

%description
These are tools for UDF file systems as used, e.g., on DVD-ROMs.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure

make %{?_smp_mflags}

%install
%make_install  %{?_smp_mflags}

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/udftools %{buildroot}%{_docdir}/udftools
rm -r %{buildroot}%{_datadir}/doc

%files
%{_bindir}/cdrwtool
%{_bindir}/udfinfo
%{_bindir}/wrudf
%{_sbindir}/mkfs.udf
%{_sbindir}/mkudffs
%{_sbindir}/pktsetup
%{_sbindir}/pktcdvd-check
%{_sbindir}/udflabel
%{_mandir}/man1/cdrwtool.1%{?ext_man}
%{_mandir}/man1/udfinfo.1%{?ext_man}
%{_mandir}/man1/wrudf.1%{?ext_man}
%{_mandir}/man8/mkfs.udf.8%{?ext_man}
%{_mandir}/man8/mkudffs.8%{?ext_man}
%{_mandir}/man8/pktsetup.8%{?ext_man}
%{_mandir}/man8/udflabel.8%{?ext_man}
%{_udevrulesdir}/80-pktsetup.rules

%changelog
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 2.3:
  * mkudffs:
  * Added support for creating Multisession UDF disc images via new --startblock option
  * Added new options for specifying owner, organization and contact information
  * Added new option --bootarea=mbr:sec-size to allow specifying MBR sector size
  * Added udftools version string into Application Identifier
  * Fixed default value of Packet Length in Sparable Partition for UDF 1.50 and 2.00 rev to 32 blocks
  * Fixed detecting all 33 types of optical discs defined in all versions of SCSI MMC specifications
  * Fixed filling CHS sector number into MBR partition table
  * Fixed alignment of VAT block for CD-R, DVD-R and BD-R disc
  * Fixed alignment for CD-R discs
  * Fixed generating unclosed CD-R image with blocks more than 3072
  * udfinfo & udflabel:
  * Added support for Multisession UDF optical discs via new --startblock and --lastblock options
  * Added support for showing and changing owner, organization, contact, appid and impid UDF identifiers
  * Added more checks to validation of UDF structures
  * Throw error when trying to modify UDF disc with unsupported Pseudo OverWrite partition
  * pktsetup:
  * Added new option -i to ignore errors when device is already mapped or unmapped
  * Added new tool pktcdvd-check which checks if optical disc can be used by kernel pktcdvd.ko driver for write operations
  * Update udev rule to map only optical discs which are supported for write operation (check done by pktcdvd-check tool)
  * cdrwtool:
  * Fixed formatting of CD-RW disc in modern optical drives according to MMC-6 standard (via Format Code 1)
  * Fixed support for progress bar
* Thu Jan 23 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: Allow OBS
  to shortcut through the -mini flavors.
* Thu Jan  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2.2
  * Allow to build udftools without udev
  * Use standard ISO C99 features instead of GCC extensions
  * Detect optional readline dependency via pkg-config when possible
  * Added support for UTF-16 surrogate pairs
  * udfinfo & udflabel:
    Added support for UDF 2.50 and UDF 2.60 revisions
    Fixed calculating free space blocks
    In read-only mode throw warning when device is busy
    Do not fail on disks with too many Sparing Tables
    Show and respect UDF write protect flags
  * mkudffs:
    Fixed accessing invalid memory on disks with small number of sectors
    Added new option --read-only which sets UDF disk to read-only mode
    Adjust partition size to work around Windows chkdsk bug
    Autodetect media type
* Mon Jan 28 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2.1
- Changes in 2.0
  * For UDF uuid is used same algorithm as in util-linux v2.30
  * Fixed Unicode encode/decode functions to correctly process OSTA Unicode
    d-string and d-characters
  * New tool udfinfo which shows various information about UDF (incuding label,
    uuid, free space)
  * New tool udflabel which shows or changes UDF label or UDF uuid
  * pktsetup:
    Make dev_name argument for setup optional
    Allow to setup and remove optical device by major:minor numbers
    Include udev rule file for automatic managing of packet writing devices
  * mkudffs:
    Fixed support for VAT and CD-R disks
    Fixed crashes and infinite loops on disks with small number of sectors
    Allow to enable VAT via new --vat option for any disk type
    Allow to enable Sparing Table via --spartable option also for any disk type
  Allow to specify number of entries in Sparing Table via new --sparspace
    option
    Added support for CD-ROM, DVD-R and BD-R discs
    Added new option --new-file for enforcing to create a new image file
    Added new option --mode for specifying permissions of root directory
  Added new option --locale for specifying that command line arguments
    are encoded according to current locale and make it default
  Added support for disks which have logical sector size 8192, 16384 or
    32768 bytes
    Check that block device is not mounted before format process starts
- Changes in 2.1
  * Fixed compilation with glibc >= 2.25
  * Allow to compile without libreadline
  * Use pkgconfig for detection of udev rules directory
  * Set minimal version of autoconf to 2.64
  * Enforce ISO C99 compiler
  * Fixed support for big endian systems
  * Fixed converting strings to integers
  * Added support for UDF 1.50 Logical Volume Extended Information (contains
    volume label)
  * Added support for UDF 1.01 revision
  * Added workaround for Year 2038 Bug
  * udfinfo & udflabel:
  Fixed accessing disks when MVDS and RVDS descriptors points to same
    location
    Fixed support for disks >= 4GB on 32bit systems
    Implemented reading VAT outside of outside of ICB
    Various fixes for reading UDF descriptors
  * mkudffs:
    Space optimization for small disks
  Allow to set alignment of UDF structures via --packetlen option for any
    media type
    Fixed alignment of VAT and generation of DVD-R and BD-R discs
  * cdrwtool:
    Disallow specifying unsupported UDF revisions
* Sat Jan 28 2017 idonmez@suse.com
- Update to version 1.3
  * No changelog upstream, see upstream git log
    https://github.com/pali/udftools/compare/1.2...1.3
- Drop cdmrw.c and cdmrw-include.patch, they are outdated.
* Fri Dec 16 2016 idonmez@suse.com
- Update to the maintained version
  Changes in 1.2
  * Manpage redirect for mkfs.udf(8)
  * Manpage fix for pktsetup(8)
  * Fixed compile and install procedure
  * Fixed parsing cdrwtool --file parameter
  Changes in 1.1
  * Included various patches from Linux distributions
  * Lots of fixes for compilation, crashes, buffer overflows,
    memory corruptions, reading from uninitialized memory, etc.
  * Fixed UTF-8 support
  * Fixed detection of device blocksize
  * Corrections and updates in man pages
  * mkudffs:
  * Set first 16 chars of Volume Set Identifier to timestamp and
    random value
  * Set default block-size to device logical block (sector) size
  * Add support for label and uuid options
  * Add support for setting uid and gid of the root directory
  * Fixed support for UDF 1.02
  * Symlink to mkfs.udf
- Drop all the patches:
  udftools-1.0.0b3-extend-extsize.patch
  udftools-1.0.0b3-pktsetup-chardev.patch,
  udftools-HZ.patch, udftools-gcc4.patch,
  udftools-include.patch, udftools-open.patch,
  udftools-wrong-memset.patch, udftools-1.0.0b3.dif
* Mon Nov 16 2015 wolfgang.engel@suse.com
- Adding patch for fixing segfault (bnc#743773)
  File: udftools-1.0.0b3-extend-extsize.patch
* Mon Jun  8 2015 schwab@suse.de
- Force gnu89 inline semantics
* Fri Nov  7 2014 mpluskal@suse.com
- Add license
- Clean up spec file
- Remove static library
* Tue Dec 27 2011 idonmez@suse.com
- Fix wrong size parameter in memset call
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Oct  4 2011 uli@suse.com
- cross-build fix: use %%__cc, %%configure macros
* Sat Jan 12 2008 coolo@suse.de
- fix build with glibc 2.7
* Thu Jan 10 2008 coolo@suse.de
- fix includes
* Mon Aug  7 2006 ro@suse.de
- use sysconf(_SC_CLK_TCK) instead of HZ
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct  4 2005 sbrabec@suse.cz
- Added cdmrw for preformatting of CD-MRW media.
- Fixed missing includes.
* Wed Jun 15 2005 hvogel@suse.de
- Update to 1.0.0b3
* Thu Nov  6 2003 schwab@suse.de
- Fix quoting in configure script.
* Wed Jun 12 2002 ro@suse.de
- fixed build for bigendian
* Thu Apr 25 2002 uli@suse.de
- fixed for lib64
* Tue Apr  2 2002 ro@suse.de
- use AC_LIBOBJ for new automake/autoconf
* Tue Feb 26 2002 ro@suse.de
- copy/rename from udf package
- update to 1.0.0b2
* Wed Oct 10 2001 stepan@suse.de
- use kernel-source instead of lx_sus22 to get package
  working on ia64, too. Kernel 2.4 is default now anyways.
* Mon Apr  2 2001 uli@suse.de
- update -> 0.9.3
- don't build module (it's not going into the package anyway)
* Fri Dec  1 2000 ro@suse.de
- use lx_sus22 for now
* Thu Oct 26 2000 ro@suse.de
- LFS fixed
* Tue Jun 20 2000 ro@suse.de
- fixed make oldconfig
* Tue Mar  7 2000 ro@suse.de
- don't try to compile packet-writing tools
* Mon Mar  6 2000 ro@suse.de
- update to 0.9.1
- removed module from filelist (in suse-kernel now)
* Fri Jan 28 2000 ro@suse.de
- update to 0.9.0
* Sat Oct 30 1999 ro@suse.de
- update to 0.8.9.3: they finally fixed the "73-files-in-a-dir" bug
* Sun Oct 17 1999 ro@suse.de
- make oldconfig with 'yes "n"'
* Mon Oct 11 1999 ro@suse.de
- update to 0.8.9.2 / fixed configure script
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 20 1999 ro@suse.de
- update to 0.8.8
- hack to compile on alpha
* Tue Aug 10 1999 uli@suse.de
- update -> 0.8.7
* Thu Jun  3 1999 uli@suse.de
- update 0.8.3 -> 0.8.5
* Mon May  3 1999 ro@suse.de
- use kernmod's .config on alpha as well
* Sun May  2 1999 ro@suse.de
- specfile fix for kernelconfig
* Sat May  1 1999 ro@suse.de
- use kernelconfig from kernmod-package
* Thu Apr 29 1999 ro@suse.de
- update to 0.8.3
* Thu Apr  8 1999 ro@suse.de
- update to 0.8.2
* Thu Mar 11 1999 uli@suse.de
- added missing doc files
* Thu Mar 11 1999 uli@suse.de
- new package, version 0.8
